from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from fastapi.staticfiles import StaticFiles

from .routers import router
from .settings import SETTINGS

app = FastAPI(
    title="Advent22 API",
    description="This API enables the `Advent22` service.",
    contact={
        "name": "Jörn-Michael Miehe",
        "email": "jmm@yavook.de",
    },
    license_info={
        "name": "MIT License",
        "url": "https://opensource.org/licenses/mit-license.php",
    },
    openapi_url=SETTINGS.openapi_url,
    docs_url=SETTINGS.docs_url,
    redoc_url=SETTINGS.redoc_url,
)

app.include_router(router)

if SETTINGS.production_mode:
    # Mount frontend in production mode
    app.mount(
        path="/",
        app=StaticFiles(
            directory=SETTINGS.ui_directory,
            html=True,
        ),
        name="frontend",
    )

else:
    # Allow CORS in debug mode
    app.add_middleware(
        CORSMiddleware,
        allow_credentials=True,
        allow_origins=["*"],
        allow_methods=["*"],
        allow_headers=["*"],
        expose_headers=["*"],
    )
